@@ -3,25 +3,25 @@ package Data::Peek;
 use strict;
 use warnings;
 
-use DynaLoader ();
+use XSLoader;
 
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION   = "0.46";
-@ISA       = qw( DynaLoader Exporter );
+$VERSION   = "0.51";
+@ISA       = qw( Exporter );
 @EXPORT    = qw( DDumper DTidy DDsort DPeek DDisplay DDump DHexDump
 		 DDual DGrow );
 @EXPORT_OK = qw( triplevar :tidy );
 push @EXPORT, "DDump_IO";
 
-bootstrap Data::Peek $VERSION;
+XSLoader::load ("Data::Peek", $VERSION);
 
 our $has_perlio;
 our $has_perltidy;
 
 BEGIN {
     use Config;
-    $has_perlio   = ($Config{useperlio} || "undef") eq "define";
-    $has_perltidy = eval q{use Perl::Tidy; $Perl::Tidy::VERSION};
+    $has_perlio   = ($Config{'useperlio'} || "undef") eq "define";
+    $has_perltidy = eval { require Perl::Tidy; $Perl::Tidy::VERSION };
     }
 
 ### ############# DDumper () ##################################################
@@ -34,39 +34,51 @@ my %sk = (
     0		=> 0,
     1		=> 1,
 
-    V	=> sub {	# Sort by value
+    'R'   => sub {	# Sort reverse
 	    my $r = shift;
-	    [         sort { $r->{$a} cmp $r->{$b} } keys %$r ];
+	    [ reverse sort                           keys %{$r} ];
 	    },
-    VN	=> sub {	# Sort by value numeric
+    'N'   => sub {	# Sort by key numerical
 	    my $r = shift;
-	    [         sort { $r->{$a} <=> $r->{$b} } keys %$r ];
+	    [         sort {      $a  <=>      $b  } keys %{$r} ];
 	    },
-    VNR	=> sub {	# Sort by value numeric reverse
+    'NR'  => sub {	# Sort by key numerical reverse
 	    my $r = shift;
-	    [         sort { $r->{$b} <=> $r->{$a} } keys %$r ];
+	    [         sort {      $b  <=>      $a  } keys %{$r} ];
 	    },
-    VR	=> sub {	# Sort by value reverse
+    'V'   => sub {	# Sort by value
 	    my $r = shift;
-	    [         sort { $r->{$b} cmp $r->{$a} } keys %$r ];
+	    [         sort { $r->{$a} cmp $r->{$b} } keys %{$r} ];
 	    },
-    R	=> sub {	# Sort reverse
+    'VN'  => sub {	# Sort by value numeric
 	    my $r = shift;
-	    [ reverse sort                           keys %$r ];
+	    [         sort { $r->{$a} <=> $r->{$b} } keys %{$r} ];
+	    },
+    'VNR' => sub {	# Sort by value numeric reverse
+	    my $r = shift;
+	    [         sort { $r->{$b} <=> $r->{$a} } keys %{$r} ];
+	    },
+    'VR'  => sub {	# Sort by value reverse
+	    my $r = shift;
+	    [         sort { $r->{$b} cmp $r->{$a} } keys %{$r} ];
 	    },
     );
 my  $_sortkeys = 1;
 our $_perltidy = 0;
 
-sub DDsort
-{
+my %pmap = map {( $_ => $_ )} map {( split //, $_ )}
+    q{ !""#$%&'()*+,-./0123456789:;<=>},
+    q{@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^},
+    q{`abcdefghijklmnopqrstuvwxyz|~}, "{}";
+$pmap{$_} = "." for grep { !exists $pmap{$_} } map { chr } 0 .. 255;
+
+sub DDsort {
     @_ or return;
 
     $_sortkeys = exists $sk{$_[0]} ? $sk{$_[0]} : $_[0];
     } # DDsort
 
-sub import
-{
+sub import {
     my @exp = @_;
     my @etl;
     foreach my $p (@exp) {
@@ -82,8 +94,7 @@ sub import
     __PACKAGE__->export_to_level (1, @etl);
     } # import
 
-sub DDumper
-{
+sub DDumper {
     $_perltidy and goto \&DTidy;
 
     local $Data::Dumper::Sortkeys  = $_sortkeys;
@@ -91,9 +102,10 @@ sub DDumper
     local $Data::Dumper::Quotekeys = 0;
     local $Data::Dumper::Deparse   = 1;
     local $Data::Dumper::Terse     = 1;
+    local $Data::Dumper::Purity    = 1;
     local $Data::Dumper::Useqq     = 0;	# I want unicode visible
 
-    my $s = Data::Dumper::Dumper @_;
+    my $s = Data::Dumper::Dumper (@_);
     $s =~ s/^(\s*)(.*?)\s*=>/sprintf "%s%-16s =>", $1, $2/gme;  # Align =>
     $s =~ s/\bbless\s*\(\s*/bless (/gm and $s =~ s/\s+\)([;,])$/)$1/gm;
     $s =~ s/^(?=\s*[]}](?:[;,]|$))/  /gm;
@@ -104,8 +116,7 @@ sub DDumper
     return $s;
     } # DDumper
 
-sub DTidy
-{
+sub DTidy {
     $has_perltidy or goto \&DDumper;
 
     local $Data::Dumper::Sortkeys  = $_sortkeys;
@@ -113,9 +124,10 @@ sub DTidy
     local $Data::Dumper::Quotekeys = 1;
     local $Data::Dumper::Deparse   = 1;
     local $Data::Dumper::Terse     = 1;
+    local $Data::Dumper::Purity    = 1;
     local $Data::Dumper::Useqq     = 0;
 
-    my $s = Data::Dumper::Dumper @_;
+    my $s = Data::Dumper::Dumper (@_);
     my $t;
     my @opts = (
 	# Disable stupid options in ~/.perltidyrc
@@ -126,9 +138,9 @@ sub DTidy
 	"--no-warning-output",
 	);
     # RT#99514 - Perl::Tidy memoizes .perltidyrc incorrectly
-    $has_perltidy > 20120714 and push @opts, "--no-memoize";
+    $has_perltidy > 20120714 and push @opts => "--no-memoize";
 
-    Perl::Tidy::perltidy (source => \$s, destination => \$t, argv => \@opts);
+    Perl::Tidy::perltidy ('source' => \$s, 'destination' => \$t, 'argv' => \@opts);
     $s = $t;
 
     defined wantarray or warn $s;
@@ -137,8 +149,7 @@ sub DTidy
 
 ### ############# DDump () ####################################################
 
-sub _DDump_ref
-{
+sub _DDump_ref {
     my (undef, $down) = (@_, 0);
 
     my $ref = ref $_[0];
@@ -164,8 +175,7 @@ sub _DDump_ref
     undef;
     } # _DDump_ref
 
-sub _DDump
-{
+sub _DDump {
     my (undef, $down, $dump, $fh) = (@_, "");
 
     if ($has_perlio and open $fh, ">", \$dump) {
@@ -181,23 +191,22 @@ sub _DDump
     return $dump;
     } # _DDump
 
-sub DDump ($;$)
-{
-    my (undef, $down) = (@_, 0);
-    my @dump = split m/[\r\n]+/, _DDump ($_[0], wantarray || $down) or return;
+sub DDump {
+    my $down = @_ > 1 ? $_[1] : 0;
+    my @dump = split m/[\r\n]+/, _DDump (@_ ? $_[0] : $_, wantarray || $down) or return;
 
     if (wantarray) {
 	my %hash;
-	($hash{sv} = $dump[0]) =~ s/^SV\s*=\s*//;
+	($hash{'sv'} = $dump[0]) =~ s/^SV\s*=\s*//;
 	m/^\s+(\w+)\s*=\s*(.*)/ and $hash{$1} = $2 for @dump;
 
-	if (exists $hash{FLAGS}) {
-	    $hash{FLAGS} =~ tr/()//d;
-	    $hash{FLAGS} = { map { $_ => 1 } split m/,/ => $hash{FLAGS} };
+	if (exists $hash{'FLAGS'}) {
+	    $hash{'FLAGS'} =~ tr/()//d;
+	    $hash{'FLAGS'} = { map {( $_ => 1 )} split m/,/ => $hash{'FLAGS'} };
 	    }
 
 	$down && ref $_[0] and
-	    $hash{RV} = _DDump_ref ($_[0], $down - 1) || $_[0];
+	    $hash{'RV'} = _DDump_ref ($_[0], $down - 1) || $_[0];
 	return %hash;
 	}
 
@@ -208,8 +217,7 @@ sub DDump ($;$)
     warn $dump;
     } # DDump
 
-sub DHexDump
-{
+sub DHexDump {
     use bytes;
     my $off = 0;
     my @out;
@@ -224,7 +232,7 @@ sub DHexDump
 	$out .= " ";
 	$out .= " ".($b[$_]||"  ") for 8 .. 15;
 	$out .= "  ";
-	$out .= ($_ < 0x20 || $_ >= 0x7f ? "." : chr $_) for map { hex $_ } @b;
+	$out .= $pmap{$_} for map { chr hex $_ } @b;
 	push @out, $out."\n";
 	$off += 16;
 	}
@@ -274,7 +282,7 @@ Data::Peek - A collection of low-level debug facilities
  my $x = ""; DGrow ($x, 10000);
  my $tv = triplevar ("\N{GREEK SMALL LETTER PI}", 3, "3.1415");
  DDsort ("R");
- DDumper [ $x ]; # use of :tidy make DDumper behave as DTidy
+ DDumper [ $x ]; # use of :tidy makes DDumper behave like DTidy
 
 =head1 DESCRIPTION
 
@@ -302,7 +310,7 @@ result is further beautified to meet my needs:
   * arrows for hashes are aligned at 16 (longer keys don't align)
   * closing braces and brackets are now correctly aligned
 
-In void context, C<DDumper ()> warn ()'s.
+In void context, C<DDumper> C<warn>'s.
 
 Example
 
@@ -338,13 +346,15 @@ If L<Perl::Tidy> is not available, C<DTidy> will fallback to C<DDumper>.
 
 This idea was shamelessly copied from John McNamara's L<Data::Dumper::Perltidy>.
 
-=head2 DDsort ( 0 | 1 | R | V | VR | VN | VNR )
+=head2 DDsort ( 0 | 1 | R | N | NR | V | VR | VN | VNR )
 
 Set the hash sort algorithm for DDumper. The default is to sort by key value.
 
   0   - Do not sort
   1   - Sort by key
   R   - Reverse sort by key
+  N   - Sort by key numerical
+  NR  - Sort by key numerical descending
   V   - Sort by value
   VR  - Reverse sort by value
   VN  - Sort by value numerical
@@ -371,8 +381,8 @@ These can also be passed to import:
 
 =head2 DPeek ($var)
 
-Playing with C<sv_dump ()>, I found C<Perl_sv_peek ()>, and it might be
-very useful for simple checks. If C<$var> is omitted, uses $_.
+Playing with C<sv_dump>, I found C<Perl_sv_peek>, and it might be very
+useful for simple checks. If C<$var> is omitted, uses $_.
 
 Example
 
@@ -380,7 +390,7 @@ Example
 
   PV("abc\nde\342\202\254fg"\0) [UTF8 "abc\nde\x{20ac}fg"]
 
-In void context, C<DPeek ()> prints to C<STDERR> plus a newline.
+In void context, C<DPeek> prints to C<STDERR> plus a newline.
 
 =head2 DDisplay
 
@@ -388,9 +398,9 @@ In void context, C<DPeek ()> prints to C<STDERR> plus a newline.
 
 Show the PV content of a scalar the way perl debugging would have done.
 UTF-8 detection is on, so this is effectively the same as returning the
-first part the C<DPeek ()> returns for non-UTF8 PV's or the second part
-for UTF-8 PV's. C<DDisplay ()> returns the empty string for scalars that
-no have a valid PV.
+first part the C<DPeek> returns for non-UTF8 PV's or the second part for
+UTF-8 PV's. C<DDisplay> returns the empty string for scalars that no
+have a valid PV.
 
 Example
 
@@ -398,7 +408,7 @@ Example
 
   "abc\nde\x{20ac}fg"
 
-In void context, C<DDisplay ()> uses C<warn> to display the result.
+In void context, C<DDisplay> uses C<warn> to display the result.
 
 =head2 DHexDump
 
@@ -466,40 +476,41 @@ not shrink.
 
 =head2 my $tp = triplevar ($pv, $iv, $nv)
 
-When making C<DDual ()> I wondered if it were possible to create triple-val
-scalar variables. L<Scalar::Util> already gives us C<dualvar ()>, that creates
+When making C<DDual> I wondered if it were possible to create triple-val
+scalar variables. L<Scalar::Util> already gives us C<dualvar>, that creates
 you a scalar with different numeric and string values that return different
-values in different context. Not that C<triplevar ()> would be very useful,
-compared to C<dualvar ()>, but at least this shows that it is possible.
+values in different context. Not that C<triplevar> would be very useful,
+compared to C<dualvar>, but at least this shows that it is possible.
 
-C<triplevar ()> is not exported by default.
+C<triplevar> is not exported by default.
 
 Example:
 
-  print DPeek for DDual
-      Data::Peek::triplevar ("\N{GREEK SMALL LETTER PI}", 3, 3.1415);
+  DDual Data::Peek::triplevar ("\N{GREEK SMALL LETTER PI}", 3, 3.1415);
 
-  PV("\317\200"\0) [UTF8 "\x{3c0}"]
-  IV(3)
-  NV(3.1415)
-  SV_UNDEF
-  IV(0)
+  PVNV("\317\200"\0) [UTF8 "\x{3c0}"]
+    PV: PV("\317\200"\0) [UTF8 "\x{3c0}"]
+    IV: IV(3)
+    NV: NV(3.1415)
+    RV: SV_UNDEF
 
-=head2 DDump ($var [, $dig_level])
+=head2 DDump ([$var [, $dig_level]])
 
 A very useful module when debugging is C<Devel::Peek>, but is has one big
 disadvantage: it only prints to STDERR, which is not very handy when your
 code wants to inspect variables at a low level.
 
-Perl itself has C<sv_dump ()>, which does something similar, but still
-prints to STDERR, and only one level deep.
+Perl itself has C<sv_dump>, which does something similar, but still prints
+to STDERR, and only one level deep.
 
-C<DDump ()> is an attempt to make the innards available to the script level
-with a reasonable level of compatibility. C<DDump ()> is context sensitive.
+C<DDump> is an attempt to make the innards available to the script level
+with a reasonable level of compatibility. C<DDump> is context sensitive.
 
-In void context, it behaves exactly like C<Perl_sv_dump ()>.
+In void context, it behaves exactly like C<Perl_sv_dump>.
 
-In scalar context, it returns what C<Perl_sv_dump ()> would have printed.
+In scalar context, it returns what C<Perl_sv_dump> would have printed.
+
+The default for the first argument is C<$_>.
 
 In list context, it returns a hash of the variable's properties. In this mode
 you can pass an optional second argument that determines the depth of digging.
@@ -591,7 +602,7 @@ Example
 
 =head2 DDump_IO ($io, $var [, $dig_level])
 
-A wrapper function around perl's internal C<Perl_do_sv_dump ()>, which
+A wrapper function around perl's internal C<Perl_do_sv_dump>, which
 makes C<Devel::Peek> completely superfluous.
 
 Example
@@ -661,18 +672,18 @@ Example
 
 =head1 INTERNALS
 
-C<DDump ()> uses an XS wrapper around C<Perl_sv_dump ()> where the
-STDERR is temporarily caught to a pipe. The internal XS helper functions
-are not meant for user space
+C<DDump> uses an XS wrapper around C<Perl_sv_dump> where the STDERR is
+temporarily caught to a pipe. The internal XS helper functions are not
+meant for user space
 
 =head2 DDump_XS (SV *sv)
 
-Base interface to internals for C<DDump ()>.
+Base interface to internals for C<DDump>.
 
 =head1 BUGS
 
 Windows and AIX might be using a build where not all symbols that were
-supposed to be exported in the public API are not. Perl_pv_peek () is
+supposed to be exported in the public API are not. C<Perl_pv_peek> is
 one of them.
 
 Not all types of references are supported.
@@ -687,11 +698,11 @@ L<Data::Dump::Streamer>, L<Data::Dumper::Perltidy>, L<Perl::Tidy>.
 
 =head1 AUTHOR
 
-H.Merijn Brand <h.m.brand@xs4all.nl>
+H.Merijn Brand <hmbrand@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2016 H.Merijn Brand
+Copyright (C) 2008-2022 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
